@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_610
 from fireREST.fmc import Connection, Resource
 from fireREST.fmc.deployment.deployabledevice.deployment import Deployment
 from fireREST.fmc.deployment.deployabledevice.pendingchanges import PendingChanges
@@ -6,8 +7,7 @@ from fireREST.fmc.deployment.deployabledevice.pendingchanges import PendingChang
 class DeployableDevice(Resource):
     PATH = '/deployment/deployabledevices/{uuid}'
     SUPPORTED_PARAMS = ['group_dependency']
-    IGNORE_FOR_UPDATE = []
-    MINIMUM_VERSION_REQUIRED_GET = '6.1.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_610
 
     def __init__(self, conn: Connection):
         self.deployment = Deployment(conn)
