@@ -1,6 +1,7 @@
+from fireREST.defaults import API_RELEASE_610
 from fireREST.fmc import Resource
 
 
 class DeploymentRequest(Resource):
     PATH = '/deployment/deploymentrequests/{uuid}'
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.1.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_610
