@@ -1,8 +1,8 @@
+from fireREST.defaults import API_RELEASE_670
 from fireREST.fmc import Resource
 
 
 class JobHistory(Resource):
     PATH = '/deployment/jobhistories/{uuid}'
     SUPPORTED_FILTERS = ['device_uuid']
-    IGNORE_FOR_UPDATE = []
-    MINIMUM_VERSION_REQUIRED_GET = '6.7.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_670
