@@ -1,6 +1,7 @@
 from typing import Dict
 
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_630
 from fireREST.fmc import Connection, Resource
 from fireREST.fmc.device.devicerecord import DeviceRecord
 
@@ -11,7 +12,7 @@ class Device(Resource):
 
         self.devicerecord = DeviceRecord(conn)
 
-    @utils.minimum_version_required(version='6.3.0')
+    @utils.minimum_version_required(version=API_RELEASE_630)
     def copyconfigrequest(self, data: Dict):
         url = self.url(path='/devices/copyconfigrequests')
         return self.conn.post(url=url, data=data)
