@@ -1,4 +1,5 @@
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_660
 from fireREST.fmc import ChildResource
 
 
@@ -10,7 +11,7 @@ class Metric(ChildResource):
 
     @utils.support_params
     @utils.resolve_by_name
-    @utils.minimum_version_required(version='6.6.0')
+    @utils.minimum_version_required(version=API_RELEASE_660)
     def get(self, metric: str, container_uuid=None, container_name=None, params=None):
         url = self.url(self.PATH.format(container_uuid=container_uuid))
         return self.conn.get(url=url, params=params)
