@@ -1,6 +1,5 @@
-from typing import Dict
-
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_610
 from fireREST.fmc import ChildResource
 
 
@@ -9,8 +8,8 @@ class PhysicalInterface(ChildResource):
     CONTAINER_PATH = '/devices/devicerecords/{uuid}'
     PATH = '/devices/devicerecords/{container_uuid}/physicalinterfaces/{uuid}'
     SUPPORTED_PARAMS = ['name']
-    MINIMUM_VERSION_REQUIRED_GET = '6.1.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.1.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_610
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_610
 
     @utils.support_params
     def get(self, container_uuid=None, container_name=None, uuid=None, name=None, params=None):
