@@ -1,6 +1,5 @@
-from typing import Dict
-
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_650
 from fireREST.fmc import ChildResource
 
 
@@ -9,19 +8,13 @@ class VlanInterface(ChildResource):
     CONTAINER_PATH = '/devices/devicerecords/{uuid}'
     PATH = '/devices/devicerecords/{container_uuid}/vlaninterfaces/{uuid}'
     SUPPORTED_PARAMS = ['name']
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.5.0'
-    MINIMUM_VERSION_REQUIRED_GET = '6.5.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.5.0'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.5.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_650
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_650
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_650
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_650
 
     @utils.support_params
     def get(self, container_uuid=None, container_name=None, uuid=None, name=None, params=None):
         return super().get(
             container_uuid=container_uuid, container_name=container_name, uuid=uuid, name=name, params=params
         )
-
-    @utils.support_params
-    def delete(self, container_uuid=None, container_name=None, uuid=None, name=None, params=None):
-        return super().delete(
-            container_uuid=container_uuid, container_name=container_name, uuid=uuid, name=name, params=params
-        )
