@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_630
 from fireREST.fmc import ChildResource
 
 
@@ -5,7 +6,7 @@ class FailoverInterfaceMacAddressConfig(ChildResource):
     CONTAINER_NAME = 'FtdDeviceHAPair'
     CONTAINER_PATH = '/devicehapairs/ftddevicehapairs/{uuid}'
     PATH = '/devicehapairs/ftddevicehapairs/{container_uuid}/failoverinterfacemacaddressconfigs/{uuid}'
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.3.0'
-    MINIMUM_VERSION_REQUIRED_GET = '6.3.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.3.0'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.3.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_630
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_630
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_630
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_630
