@@ -1,11 +1,11 @@
+from fireREST.defaults import API_RELEASE_610
 from fireREST.exceptions import UnsupportedOperationError
 from fireREST.fmc import Resource
 
 
 class TaskStatus(Resource):
     PATH = '/job/taskstatuses/{uuid}'
-    IGNORE_FOR_UPDATE = []
-    MINIMUM_VERSION_REQUIRED_GET = '6.1.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_610
 
     def get(self, uuid=None, name=None, params=None):
         if not uuid:
