@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_700
 from fireREST.fmc import ChildResource
 
 
@@ -5,4 +6,4 @@ class Override(ChildResource):
     CONTAINER_NAME = 'AnyconnectCustomAttribute'
     CONTAINER_PATH = '/object/anyconnectcustomattributes/{uuid}'
     PATH = '/object/anyconnectcustomattributes/{container_uuid}/overrides/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '7.0.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_700
