@@ -1,10 +1,14 @@
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_700, API_RELEASE_720
 from fireREST.fmc import Resource, Connection
 
 
 class AnyconnectProfile(Resource):
     PATH = '/object/anyconnectprofiles/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '7.0.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_720
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_700
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_720
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_720
 
     SUPPORTED_FILTERS = ['name_or_value', 'unused_only']
 
