@@ -1,14 +1,15 @@
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_630
 from fireREST.fmc import Resource, Connection
 from fireREST.fmc.object.dnsservergroup.override import Override
 
 
 class DnsServerGroup(Resource):
     PATH = '/object/dnsservergroups/{uuid}'
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.3.0'
-    MINIMUM_VERSION_REQUIRED_GET = '6.3.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.3.0'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.3.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_630
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_630
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_630
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_630
 
     SUPPORTED_PARAMS = ['override_target_id']
 
