@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_630
 from fireREST.fmc import ChildResource
 
 
@@ -5,4 +6,4 @@ class Override(ChildResource):
     CONTAINER_NAME = 'Fqdn'
     CONTAINER_PATH = '/object/fqdns/{uuid}'
     PATH = '/object/fqdns/{container_uuid}/overrides/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '6.3.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_630
