@@ -1,12 +1,17 @@
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_700, API_RELEASE_720
 from fireREST.fmc import Resource, Connection
 from fireREST.fmc.object.ipv6addresspool.override import Override
 
 
 class Ipv6AddressPool(Resource):
     PATH = '/object/ipv6addresspools/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '7.0.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_700
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_720
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_720
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_720
 
+    SUPPORTED_FILTERS = ['name_or_value', 'unused_only']
     SUPPORTED_PARAMS = ['override_target_id']
 
     def __init__(self, conn: Connection):
