@@ -1,13 +1,14 @@
+from fireREST.defaults import API_RELEASE_640
 from fireREST.fmc import Resource, Connection
 from fireREST.fmc.object.keychain.override import Override
 
 
 class KeyChain(Resource):
     PATH = '/object/keychains/{uuid}'
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.4.0'
-    MINIMUM_VERSION_REQUIRED_GET = '6.4.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.4.0'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.4.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_640
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_640
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_640
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_640
 
     def __init__(self, conn: Connection):
         super().__init__(conn)
