@@ -1,6 +1,7 @@
+from fireREST.defaults import API_RELEASE_623
 from fireREST.fmc import Resource
 
 
 class SiUrlList(Resource):
     PATH = '/object/siurllists/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '6.2.3'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_623
