@@ -1,14 +1,15 @@
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_660
 from fireREST.fmc import Resource, Connection
 from fireREST.fmc.object.timezone.override import Override
 
 
 class Timezone(Resource):
     PATH = '/object/timezoneobjects/{uuid}'
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.6.0'
-    MINIMUM_VERSION_REQUIRED_GET = '6.6.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.6.0'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.6.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_660
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_660
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_660
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_660
 
     SUPPORTED_PARAMS = ['override_target_id']
 
