@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_660
 from fireREST.fmc import ChildResource
 
 
@@ -5,4 +6,4 @@ class Override(ChildResource):
     CONTAINER_NAME = 'Timezone'
     CONTAINER_PATH = '/object/timezoneobjects/{uuid}'
     PATH = '/object/timezoneobjects/{container_uuid}/overrides/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '6.6.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_660
