@@ -1,6 +1,7 @@
 from typing import Union
 
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_610, API_RELEASE_621
 from fireREST.fmc import ChildResource
 
 
@@ -9,10 +10,10 @@ class AccessRule(ChildResource):
     CONTAINER_PATH = '/policy/accesspolicies/{uuid}'
     PATH = '/policy/accesspolicies/{container_uuid}/accessrules/{uuid}'
     SUPPORTED_PARAMS = ['category', 'section', 'insert_before', 'insert_after']
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.2.1'
-    MINIMUM_VERSION_REQUIRED_GET = '6.1.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.1.0'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.1.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_621
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_610
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_610
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_610
 
     @utils.support_params
     def create(
