@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_700
 from fireREST.fmc import ChildResource
 
 
@@ -5,4 +6,4 @@ class SecurityIntelligencePolicy(ChildResource):
     CONTAINER_NAME = 'AccessPolicy'
     CONTAINER_PATH = '/policy/accesspolicies/{uuid}'
     PATH = '/policy/accesspolicies/{container_uuid}/securityintelligencepolicies/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '7.0.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_700
