@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_700
 from fireREST.fmc import Connection, Resource
 from fireREST.fmc.policy.dnspolicy.allowdnsrule import AllowDnsRule
 from fireREST.fmc.policy.dnspolicy.blockdnsrule import BlockDnsRule
@@ -5,7 +6,7 @@ from fireREST.fmc.policy.dnspolicy.blockdnsrule import BlockDnsRule
 
 class DnsPolicy(Resource):
     PATH = '/policy/dnspolicies/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '7.0.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_700
 
     def __init__(self, conn: Connection):
         super().__init__(conn)
