@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_700
 from fireREST.fmc import ChildResource
 
 
@@ -5,4 +6,4 @@ class AllowDnsRule(ChildResource):
     CONTAINER_NAME = 'DnsPolicy'
     CONTAINER_PATH = '/policy/dnspolicies/{uuid}'
     PATH = '/policy/dnspolicies/{container_uuid}/allowdnsrule/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '7.0.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_700
