@@ -1,21 +1,19 @@
 from typing import Dict, Union
 
 from fireREST import utils
-from fireREST.fmc import Connection, ChildResource
+from fireREST.defaults import API_RELEASE_623
+from fireREST.fmc import ChildResource
 
 
 class AutoNatRule(ChildResource):
     CONTAINER_NAME = 'FtdNatPolicy'
     CONTAINER_PATH = '/policy/ftdnatpolicies/{uuid}'
     PATH = '/policy/ftdnatpolicies/{container_uuid}/autonatrules/{uuid}'
-    SUPPORTED_FILTERS = []
     SUPPORTED_PARAMS = ['section']
-    IGNORE_FOR_CREATE = []
-    IGNORE_FOR_UPDATE = []
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.2.3'
-    MINIMUM_VERSION_REQUIRED_GET = '6.2.3'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.2.3'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.2.3'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_623
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_623
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_623
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_623
 
     @utils.support_params
     def create(
