@@ -1,5 +1,4 @@
-from fireREST import utils
-from fireREST.defaults import API_CONFIG_NAME
+from fireREST.defaults import API_RELEASE_630
 from fireREST.fmc import Connection, Resource
 from fireREST.fmc.policy.ftds2svpn.advancedsettings import AdvancedSettings
 from fireREST.fmc.policy.ftds2svpn.endpoint import Endpoint
@@ -9,11 +8,10 @@ from fireREST.fmc.policy.ftds2svpn.ipsecsettings import IpsecSettings
 
 class FtdS2sVpn(Resource):
     PATH = '/policy/ftds2svpns/{uuid}'
-    IGNORE_FOR_UPDATE = []
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.3.0'
-    MINIMUM_VERSION_REQUIRED_GET = '6.3.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.3.0'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.3.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_630
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_630
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_630
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_630
 
     def __init__(self, conn: Connection):
         super().__init__(conn)
