@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_610, API_RELEASE_670
 from fireREST.fmc import Connection, Resource
 from fireREST.fmc.policy.intrusionpolicy.intrusionrule import IntrusionRule
 from fireREST.fmc.policy.intrusionpolicy.intrusionrulegroup import IntrusionRuleGroup
@@ -6,10 +7,10 @@ from fireREST.fmc.policy.intrusionpolicy.intrusionrulegroup import IntrusionRule
 class IntrusionPolicy(Resource):
     PATH = '/policy/intrusionpolicies/{uuid}'
     IGNORE_FOR_UPDATE = ['rules']
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.7.0'
-    MINIMUM_VERSION_REQUIRED_GET = '6.1.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.7.0'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.7.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_670
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_610
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_670
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_670
 
     def __init__(self, conn: Connection):
         super().__init__(conn)
