@@ -1,3 +1,4 @@
+from fireREST.defaults import API_RELEASE_700
 from fireREST.fmc import ChildResource
 
 
@@ -5,5 +6,5 @@ class InspectorOverrideConfig(ChildResource):
     CONTAINER_NAME = 'NetworkAnalysisPolicy'
     CONTAINER_PATH = '/policy/networkanalysispolicies/{uuid}'
     PATH = '/policy/networkanalysispolicies/{container_uuid}/inspectoroverrideconfigs/{uuid}'
-    MINIMUM_VERSION_REQUIRED_GET = '7.0.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '7.0.0'
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_700
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_700
