@@ -1,6 +1,7 @@
 from typing import Union
 
 from fireREST import utils
+from fireREST.defaults import API_RELEASE_650
 from fireREST.fmc import ChildResource
 
 
@@ -8,14 +9,11 @@ class PrefilterRule(ChildResource):
     CONTAINER_NAME = 'PrefilterPolicy'
     CONTAINER_PATH = '/policy/prefilterpolicies/{uuid}'
     PATH = '/policy/prefilterpolicies/{container_uuid}/prefilterrules/{uuid}'
-    SUPPORTED_FILTERS = []
     SUPPORTED_PARAMS = ['category', 'section', 'insert_before', 'insert_after']
-    IGNORE_FOR_CREATE = []
-    IGNORE_FOR_UPDATE = []
-    MINIMUM_VERSION_REQUIRED_CREATE = '6.5.0'
-    MINIMUM_VERSION_REQUIRED_GET = '6.5.0'
-    MINIMUM_VERSION_REQUIRED_UPDATE = '6.5.0'
-    MINIMUM_VERSION_REQUIRED_DELETE = '6.5.0'
+    MINIMUM_VERSION_REQUIRED_CREATE = API_RELEASE_650
+    MINIMUM_VERSION_REQUIRED_GET = API_RELEASE_650
+    MINIMUM_VERSION_REQUIRED_UPDATE = API_RELEASE_650
+    MINIMUM_VERSION_REQUIRED_DELETE = API_RELEASE_650
 
     @utils.support_params
     def create(
