@@ -206,41 +206,57 @@ STATE = {
 
 FILTERS = {
     'current_security_level': 'currentSecurityLevel',
-    'show_only_parents': 'showonlyparents',
-    'include_count': 'includeCount',
-    'gid': 'gid',
-    'sid': 'sid',
-    'overrides': 'overrides',
-    'ips_policy': 'ipspolicy',
+    'destination_interface': 'destinationInterface',
+    'deployed_status': 'deployedStatus',
+    'device_id': 'deviceId',
+    'device_uuids': 'deviceUUIDs',
+    'end_time': 'endTime',
+    'fetch_zero_hitcount': 'fetchZeroHitCount',
     'fts': 'fts',
-    'realm': 'realm',
+    'gid': 'gid',
+    'group_by': 'groupBy',
+    'ids': 'ids',
+    'include_count': 'includeCount',
+    'ip_address': 'ipAddress',
+    'ips_policy': 'ipspolicy',
+    'metric': 'metric',
+    'module_ids': 'moduleIDs',
     'name': 'name',
     'name_or_value': 'nameOrValue',
     'obj_type': 'type',
-    'unused_only': 'unusedOnly',
+    'overrides': 'overrides',
+    'protocol': 'protocol',
+    'port': 'port',
+    'realm': 'realm',
     'rule_ids': 'ids',
-    'device_id': 'deviceId',
-    'source_interface': 'sourceInterface',
-    'destination_interface': 'destinationInterface',
-    'original_source': 'originalSource',
+    'operation': 'operation',
     'original_destination': 'originalDestination',
-    'translated_source': 'translatedSource',
-    'translated_destination': 'translatedDestination',
-    'original_source_port': 'originalSourcePort',
     'original_destination_port': 'originalDestinationPort',
-    'translated_source_port': 'translatedSourcePort',
+    'original_source': 'originalSource',
+    'original_source_port': 'originalSourcePort',
+    'show_only_parents': 'showonlyparents',
+    'sid': 'sid',
+    'sort_by': 'sortBy',
+    'source_interface': 'sourceInterface',
+    'status': 'status',
+    'start_time': 'startTime',
+    'translated_destination': 'translatedDestination',
     'translated_destination_port': 'translatedDestinationPort',
-    'ids': 'ids',
-    'fetch_zero_hitcount': 'fetchZeroHitCount',
+    'translated_source': 'translatedSource',
+    'translated_source_port': 'translatedSourcePort',
+    'unused_only': 'unusedOnly',
+    'vpn_topology_id': 'vpnTopologyId',
+    'vuln_id': 'id',
 }
 
 PARAMS = {
-    'override_target_id': 'overrideTargetId',
     'above_category': 'aboveCategory',
-    'section': 'section',
     'category': 'category',
-    'name': 'name',
-    'insert_before': 'insertBefore',
     'insert_after': 'insertAfter',
+    'insert_before': 'insertBefore',
+    'name': 'name',
+    'override_target_id': 'overrideTargetId',
+    'section': 'section',
+    'skip_control_readiness': 'skipControlReadiness',
     'target_index': 'targetIndex',
 }
